@@ -153,6 +153,13 @@ gdaui_basic_form_class_init (GdauiBasicFormClass * class)
 			      NULL, NULL,
 			      _gdaui_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2,
 			      GDA_TYPE_HOLDER, G_TYPE_BOOLEAN);
+	/**
+	 * GdauiBasicForm::activated:
+	 * @form: GdauiBasicForm
+	 *
+	 * Emitted when the use has activated any of the #GdaDataEntry widget
+	 * in @form.
+	 */
 	gdaui_basic_form_signals[ACTIVATED] =
 		g_signal_new ("activated",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -1371,8 +1378,10 @@ gdaui_basic_form_clean (GdauiBasicForm *form)
 	if (form->priv->set) {
 		for (i = 0, list = form->priv->set->holders; 
 		     list; 
-		     i++, list = list->next)
-			g_signal_handler_disconnect (G_OBJECT (list->data), form->priv->signal_ids[i]);
+		     i++, list = list->next) {
+			if (form->priv->signal_ids[i] > 0)
+				g_signal_handler_disconnect (G_OBJECT (list->data), form->priv->signal_ids[i]);
+		}
 		g_free (form->priv->signal_ids);
 		form->priv->signal_ids = NULL;
 	}
