@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 2007 - 2008 The GNOME Foundation
+ * Copyright (C) 2007 - 2009 The GNOME Foundation
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -123,7 +123,7 @@ static void gda_data_model_dir_get_property (GObject *object,
 					     GParamSpec *pspec);
 
 /* GdaDataModel interface */
-static void                 gda_data_model_dir_data_model_init (GdaDataModelClass *iface);
+static void                 gda_data_model_dir_data_model_init (GdaDataModelIface *iface);
 static gint                 gda_data_model_dir_get_n_rows      (GdaDataModel *model);
 static gint                 gda_data_model_dir_get_n_columns   (GdaDataModel *model);
 static GdaColumn           *gda_data_model_dir_describe_column (GdaDataModel *model, gint col);
@@ -146,7 +146,7 @@ static GObjectClass *parent_class = NULL;
  * Object init and dispose
  */
 static void
-gda_data_model_dir_data_model_init (GdaDataModelClass *iface)
+gda_data_model_dir_data_model_init (GdaDataModelIface *iface)
 {
         iface->i_get_n_rows = gda_data_model_dir_get_n_rows;
         iface->i_get_n_columns = gda_data_model_dir_get_n_columns;
@@ -799,8 +799,11 @@ gda_data_model_dir_get_value_at (GdaDataModel *model, gint col, gint row, GError
 
 	if (row >= imodel->priv->rows->len) {
 		gchar *str;
-                str = g_strdup_printf (_("Row %d out of range (0-%d)"), row,
-				       imodel->priv->rows->len - 1);
+		if (imodel->priv->rows->len > 0)
+			str = g_strdup_printf (_("Row %d out of range (0-%d)"), row,
+					       imodel->priv->rows->len - 1);
+		else
+			str = g_strdup_printf (_("Row %d not found (empty data model)"), row);
 		add_error (imodel, str);
 		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_ROW_OUT_OF_RANGE_ERROR,
 			      "%s", str);
@@ -968,8 +971,11 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 
 	if (row >= imodel->priv->rows->len) {
 		gchar *str;
-                str = g_strdup_printf (_("Row %d out of range (0-%d)"), row,
-				       imodel->priv->rows->len - 1);
+		if (imodel->priv->rows->len > 0)
+			str = g_strdup_printf (_("Row %d out of range (0-%d)"), row,
+					       imodel->priv->rows->len - 1);
+		else
+			str = g_strdup_printf (_("Row %d not found (empty data model)"), row);
 		add_error (imodel, str);
 		g_set_error (error, 0, 0, "%s", str);
 		g_free (str);
@@ -1059,7 +1065,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 					return FALSE;
 				}
 				else {
-					/* renaming succedded => update FileRow */
+					/* renaming succeeded => update FileRow */
 #ifndef G_OS_WIN32
 					g_rmdir (old_path);
 #endif
@@ -1101,7 +1107,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 				return FALSE;
 			}
 			else {
-				/* renaming succedded => update FileRow */
+				/* renaming succeeded => update FileRow */
 				gda_value_free (frow->filename_value);
 				frow->filename_value = gda_value_copy (value);
 				if (frow->raw_filename_value) {
@@ -1315,8 +1321,11 @@ gda_data_model_dir_remove_row (GdaDataModel *model, gint row, GError **error)
 
 	if (row >= imodel->priv->rows->len) {
 		gchar *str;
-                str = g_strdup_printf (_("Row %d out of range (0-%d)"), row,
-				       imodel->priv->rows->len - 1);
+		if (imodel->priv->rows->len > 0)
+			str = g_strdup_printf (_("Row %d out of range (0-%d)"), row,
+					       imodel->priv->rows->len - 1);
+		else
+			str = g_strdup_printf (_("Row %d not found (empty data model)"), row);
 		add_error (imodel, str);
 		g_set_error (error, 0, 0, "%s", str);
 		g_free (str);
