@@ -48,11 +48,7 @@ typedef struct _GdaServerOperation        GdaServerOperation;
 typedef struct _GdaServerOperationClass   GdaServerOperationClass;
 typedef struct _GdaServerOperationPrivate GdaServerOperationPrivate;
 
-typedef struct _GdaClient        GdaClient;
-typedef struct _GdaClientClass   GdaClientClass;
-typedef struct _GdaClientPrivate GdaClientPrivate;
-
-typedef struct _GdaDataModelClass   GdaDataModelClass;
+typedef struct _GdaDataModelIface   GdaDataModelIface;
 typedef struct _GdaDataModel        GdaDataModel;
 
 typedef struct _GdaDataProxy GdaDataProxy;
@@ -93,6 +89,9 @@ typedef struct _GdaStatement GdaStatement;
 typedef struct _GdaStatementClass GdaStatementClass;
 typedef struct _GdaStatementPrivate GdaStatementPrivate;
 
+typedef struct _GdaRepetitiveStatement GdaRepetitiveStatement;
+typedef struct _GdaRepetitiveStatementClass GdaRepetitiveStatementClass;
+
 typedef struct _GdaSqlParser GdaSqlParser;
 typedef struct _GdaSqlParserClass GdaSqlParserClass;
 typedef struct _GdaSqlParserPrivate GdaSqlParserPrivate;
@@ -109,6 +108,25 @@ typedef struct _GdaMetaStruct        GdaMetaStruct;
 typedef struct _GdaMetaStructClass   GdaMetaStructClass;
 typedef struct _GdaMetaStructPrivate GdaMetaStructPrivate;
 
+/*
+ * Determines if @word is a reserved SQL keyword
+ */
+typedef gboolean (*GdaSqlReservedKeywordsFunc) (const gchar *word);
+
+/*
+ * GdaTree
+ */
+typedef struct _GdaTree GdaTree;
+typedef struct _GdaTreeClass GdaTreeClass;
+typedef struct _GdaTreePrivate GdaTreePrivate;
+
+typedef struct _GdaTreeManager GdaTreeManager;
+typedef struct _GdaTreeManagerClass GdaTreeManagerClass;
+typedef struct _GdaTreeManagerPrivate GdaTreeManagerPrivate;
+
+typedef struct _GdaTreeNode GdaTreeNode;
+typedef struct _GdaTreeNodeClass GdaTreeNodeClass;
+typedef struct _GdaTreeNodePrivate GdaTreeNodePrivate;
 
 /*
  * Win32 adaptations
