@@ -152,7 +152,6 @@ static void
 gda_meta_struct_init (GdaMetaStruct *mstruct) {
 	mstruct->priv = g_new0 (GdaMetaStructPrivate, 1);
 	mstruct->priv->store = NULL;
-	mstruct->priv->db_objects = NULL;
 	mstruct->priv->index = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 }
 
@@ -312,12 +311,11 @@ compute_view_dependencies (GdaMetaStruct *mstruct, GdaMetaDbObject *view_dbobj,
 				tmp_obj = gda_meta_struct_complement (m2,
 								      GDA_META_DB_VIEW, NULL, NULL, vname, NULL);
 			gda_value_free (vname);
+			g_object_unref (m2);
 
-			if (!tmp_obj) {
+			if (!tmp_obj) 
 				/* could not find dependency */
-				g_object_unref (m2);
 				continue;
-			}
 
 			/* the dependency exists, and is identified by tmp_obj->obj_catalog, tmp_obj->obj_schema 
 			 * and tmp_obj->obj_name */
@@ -338,7 +336,6 @@ compute_view_dependencies (GdaMetaStruct *mstruct, GdaMetaDbObject *view_dbobj,
 						       tmp_obj->obj_schema, tmp_obj->obj_name);
 				g_hash_table_insert (mstruct->priv->index, str, ref_obj);
 			}
-			g_object_unref (m2);
 			g_assert (ref_obj);
 			gda_value_free (catalog);
 			gda_value_free (schema);
@@ -900,7 +897,13 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 					if (fk_nrows != ref_pk_nrows) {
 						/*gda_data_model_dump (fk_cols, stdout);
 						  gda_data_model_dump (ref_pk_cols, stdout);*/
-						fkerror = TRUE;
+						if (ref_pk_nrows > 0)
+							fkerror = TRUE;
+						else {
+							/* not an error, only the referenced table is not present
+							 * in the meta store, which is possible if the meta
+							 * store was only partially updated */
+						}
 					}
 					else {
 						gint n;
@@ -1034,7 +1037,7 @@ _meta_struct_complement (GdaMetaStruct *mstruct, GdaMetaDbObjectType type,
 
  onerror:
 	if (dbo)
-		dbo->obj_type = GDA_META_DB_UNKNOWN;
+		gda_meta_db_object_free (dbo);
 
 	return NULL;
 }
@@ -1293,7 +1296,7 @@ real_gda_meta_struct_complement_all (GdaMetaStruct *mstruct, gboolean default_on
  *
  * This method is similar to gda_meta_struct_complement() and gda_meta_struct_complement_all()
  * but creates #GdaMetaDbObject for all the
- * database object which are useable using only their short name (that is which do not need to be prefixed by 
+ * database object which are usable using only their short name (that is which do not need to be prefixed by 
  * the schema in which they are to be used).
  *
  * Please refer to gda_meta_struct_complement() form more information.
@@ -1784,7 +1787,6 @@ gda_meta_db_object_free_contents (GdaMetaDbObject *dbo)
 		TO_IMPLEMENT;
 	}
 	g_slist_free (dbo->depend_list);
-	memset (dbo, 0, sizeof (GdaMetaDbObject));
 }
 
 static void
@@ -2233,7 +2235,7 @@ copyerror:
  * @error: a place to store errors, or %NULL
  *
  * Adds @dbo to the database objects known to @mstruct. In any case (whether an error occured or not)
- * @dbo's responsability is then transferred to @smtruct and should
+ * @dbo's responsibility is then transferred to @smtruct and should
  * not be used after calling this function (it may have been destroyed). If you need a pointer to the #GdaMetaDbObject
  * for a database object, use gda_meta_struct_get_db_object().
  *
