@@ -25,8 +25,7 @@
 #ifndef __GDA_SQLITE_H__
 #define __GDA_SQLITE_H__
 
-#include <glib/gmacros.h>
-#include <glib/gtypes.h>
+#include <glib.h>
 #include <libgda/libgda.h>
 
 #ifdef HAVE_SQLITE
@@ -45,13 +44,6 @@ typedef struct {
 	sqlite3      *connection;
 	gchar        *file;
 	GHashTable   *types; /* key = type name, value = GType */
-	GdaDataModel *functions_model;
-	GdaDataModel *aggregates_model;
 } SqliteConnectionData;
 
-/* 
- * Utility functions
- */
-void _gda_sqlite_update_types_hash (SqliteConnectionData *scnc);
-
 #endif
