@@ -1,5 +1,5 @@
-/* GDA DB Oracle Blob
- * Copyright (C) 2007 The GNOME Foundation
+/* GDA Oracle provider
+ * Copyright (C) 2009 The GNOME Foundation
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -23,9 +23,7 @@
 #ifndef __GDA_ORACLE_BLOB_OP_H__
 #define __GDA_ORACLE_BLOB_OP_H__
 
-#include <libgda/gda-value.h>
 #include <libgda/gda-blob-op.h>
-#include <oci.h>
 
 G_BEGIN_DECLS
 
@@ -40,12 +38,12 @@ typedef struct _GdaOracleBlobOpClass   GdaOracleBlobOpClass;
 typedef struct _GdaOracleBlobOpPrivate GdaOracleBlobOpPrivate;
 
 struct _GdaOracleBlobOp {
-	GdaBlobOp               parent;
+	GdaBlobOp             parent;
 	GdaOracleBlobOpPrivate *priv;
 };
 
 struct _GdaOracleBlobOpClass {
-	GdaBlobOpClass          parent_class;
+	GdaBlobOpClass        parent_class;
 };
 
 GType         gda_oracle_blob_op_get_type     (void) G_GNUC_CONST;
