@@ -1501,8 +1501,14 @@ oracle_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context,
 		gchar *str1;
 		str1 = context->render_select (GDA_SQL_ANY_PART (expr->select), context, error);
 		if (!str1) goto err;
-		str = g_strdup_printf ("(%s)", str1);
-		g_free (str1);
+
+		if (! GDA_SQL_ANY_PART (expr)->parent ||
+		    (GDA_SQL_ANY_PART (expr)->parent->type != GDA_SQL_ANY_SQL_FUNCTION)) {
+			str = g_strdup_printf ("(%s)", str1);
+			g_free (str1);
+		}
+		else
+			str = str1;
 	}
 	else if (expr->case_s) {
 		str = context->render_case (GDA_SQL_ANY_PART (expr->case_s), context, error);
