@@ -93,7 +93,7 @@ static gboolean            gda_postgres_provider_rollback_savepoint (GdaServerPr
 static gboolean            gda_postgres_provider_delete_savepoint (GdaServerProvider *provider, GdaConnection *cnc,
 								   const gchar *name, GError **error);
 
-/* information retreival */
+/* information retrieval */
 static const gchar        *gda_postgres_provider_get_version (GdaServerProvider *provider);
 static gboolean            gda_postgres_provider_supports_feature (GdaServerProvider *provider, GdaConnection *cnc,
 								   GdaConnectionFeature feature);
@@ -212,8 +212,7 @@ gda_postgres_provider_class_init (GdaPostgresProviderClass *klass)
         provider_class->delete_savepoint = gda_postgres_provider_delete_savepoint;
 
 	provider_class->create_parser = gda_postgres_provider_create_parser;
-	provider_class->statement_to_sql = NULL; /* don't use gda_postgres_provider_statement_to_sql()
-						  * because it only calls gda_statement_to_sql_extended() */
+	provider_class->statement_to_sql = gda_postgres_provider_statement_to_sql;
 	provider_class->statement_prepare = gda_postgres_provider_statement_prepare;
 	provider_class->statement_execute = gda_postgres_provider_statement_execute;
 
@@ -260,10 +259,6 @@ gda_postgres_provider_class_init (GdaPostgresProviderClass *klass)
 	provider_class->meta_funcs.routine_col = _gda_postgres_meta_routine_col;
 	provider_class->meta_funcs._routine_par = _gda_postgres_meta__routine_par;
 	provider_class->meta_funcs.routine_par = _gda_postgres_meta_routine_par;
-	provider_class->meta_funcs._indexes_tab = _gda_postgres_meta__indexes_tab;
-        provider_class->meta_funcs.indexes_tab = _gda_postgres_meta_indexes_tab;
-        provider_class->meta_funcs._index_cols = _gda_postgres_meta__index_cols;
-        provider_class->meta_funcs.index_cols = _gda_postgres_meta_index_cols;
 
 	provider_class->xa_funcs = g_new0 (GdaServerProviderXa, 1);
 	provider_class->xa_funcs->xa_start = gda_postgres_provider_xa_start;
@@ -645,8 +640,6 @@ gda_postgres_provider_open_connection (GdaServerProvider *provider, GdaConnectio
 		pq_pwd = gda_quark_list_find (params, "PASSWORD");
 
         pq_requiressl = gda_quark_list_find (params, "USE_SSL");
-	if (pq_requiressl && (*pq_requiressl != 'T') && (*pq_requiressl != 't'))
-		pq_requiressl = NULL;
 
 	/* TODO: Escape single quotes and backslashes in the user name and password: */
         conn_string = g_strconcat ("",
@@ -902,7 +895,7 @@ gda_postgres_provider_supports_operation (GdaServerProvider *provider, GdaConnec
  * Create operation request
  *
  * Creates a #GdaServerOperation. The following code is generic and should only be changed
- * if some further initialization is required, or if operation's contents is dependant on @cnc
+ * if some further initialization is required, or if operation's contents is dependent on @cnc
  */
 static GdaServerOperation *
 gda_postgres_provider_create_operation (GdaServerProvider *provider, GdaConnection *cnc,
@@ -1607,9 +1600,6 @@ gda_postgres_provider_create_parser (GdaServerProvider *provider, GdaConnection
  * The implementation show here simply calls gda_statement_to_sql_extended() but the rendering
  * can be specialized to the database's SQL dialect, see the implementation of gda_statement_to_sql_extended()
  * and SQLite's specialized rendering for more details
- *
- * NOTE: This implementation MUST NOT call gda_statement_to_sql_extended() if it is
- *       the GdaServerProvider::statement_to_sql() virtual method's implementation
  */
 static gchar *
 gda_postgres_provider_statement_to_sql (GdaServerProvider *provider, GdaConnection *cnc,
@@ -1776,7 +1766,7 @@ make_last_inserted_set (GdaConnection *cnc, GdaStatement *stmt, Oid last_id)
 {
 	GError *lerror = NULL;
 
-	/* analyse @stmt */
+	/* analyze @stmt */
 	GdaSqlStatement *sql_insert;
 	GdaSqlStatementInsert *insert;
 	if (gda_statement_get_statement_type (stmt) != GDA_SQL_STATEMENT_INSERT)
@@ -2521,12 +2511,12 @@ pg_remove_quotes (gchar *str)
 
         total = strlen (str);
         if (str[total-1] == delim) {
-		/* string is correclty terminated */
+		/* string is correctly terminated */
 		g_memmove (str, str+1, total-2);
 		total -=2;
 	}
 	else {
-		/* string is _not_ correclty terminated */
+		/* string is _not_ correctly terminated */
 		g_memmove (str, str+1, total-1);
 		total -=1;
 	}
