@@ -85,7 +85,7 @@ static gboolean            gda_capi_provider_rollback_savepoint (GdaServerProvid
 static gboolean            gda_capi_provider_delete_savepoint (GdaServerProvider *provider, GdaConnection *cnc,
 							       const gchar *name, GError **error);
 
-/* information retreival */
+/* information retrieval */
 static const gchar        *gda_capi_provider_get_version (GdaServerProvider *provider);
 static gboolean            gda_capi_provider_supports_feature (GdaServerProvider *provider, GdaConnection *cnc,
 							       GdaConnectionFeature feature);
@@ -321,7 +321,7 @@ gda_capi_provider_get_version (GdaServerProvider *provider)
  *   - open the real connection to the database using the parameters previously checked
  *   - create a CapiConnectionData structure and associate it to @cnc
  *
- * Returns: TRUE if no error occurred, or FALSE otherwise (and an ERROR gonnection event must be added to @cnc)
+ * Returns: TRUE if no error occurred, or FALSE otherwise (and an ERROR connection event must be added to @cnc)
  */
 static gboolean
 gda_capi_provider_open_connection (GdaServerProvider *provider, GdaConnection *cnc,
@@ -372,7 +372,7 @@ gda_capi_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
  *   - Actually close the connection to the database using @cnc's associated CapiConnectionData structure
  *   - Free the CapiConnectionData structure and its contents
  *
- * Returns: TRUE if no error occurred, or FALSE otherwise (and an ERROR gonnection event must be added to @cnc)
+ * Returns: TRUE if no error occurred, or FALSE otherwise (and an ERROR connection event must be added to @cnc)
  */
 static gboolean
 gda_capi_provider_close_connection (GdaServerProvider *provider, GdaConnection *cnc)
@@ -481,7 +481,7 @@ gda_capi_provider_supports_operation (GdaServerProvider *provider, GdaConnection
  * Create operation request
  *
  * Creates a #GdaServerOperation. The following code is generic and should only be changed
- * if some further initialization is required, or if operation's contents is dependant on @cnc
+ * if some further initialization is required, or if operation's contents is dependent on @cnc
  */
 static GdaServerOperation *
 gda_capi_provider_create_operation (GdaServerProvider *provider, GdaConnection *cnc,
@@ -504,12 +504,13 @@ gda_capi_provider_create_operation (GdaServerProvider *provider, GdaConnection *
 	dir = gda_gbr_get_file_path (GDA_DATA_DIR, LIBGDA_ABI_NAME, NULL);
         file = gda_server_provider_find_file (provider, dir, str);
 	g_free (dir);
-        g_free (str);
 
         if (! file) {
-                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), file);
+                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), str);
+		g_free (str);
                 return NULL;
         }
+        g_free (str);
 
         op = gda_server_operation_new (type, file);
         g_free (file);
@@ -542,12 +543,13 @@ gda_capi_provider_render_operation (GdaServerProvider *provider, GdaConnection *
 	dir = gda_gbr_get_file_path (GDA_DATA_DIR, LIBGDA_ABI_NAME, NULL);
         file = gda_server_provider_find_file (provider, dir, str);
 	g_free (dir);
-        g_free (str);
 
         if (! file) {
-                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), file);
+                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), str);
+		g_free (str);
                 return NULL;
         }
+        g_free (str);
         if (!gda_server_operation_is_valid (op, file, error)) {
                 g_free (file);
                 return NULL;
