@@ -4,12 +4,14 @@
 #include "common.h"
 
 int 
-main(int argc, char ** argv)
+main (int argc, char ** argv)
 {
 	GdaMetaStore *store;
-	gchar *cnc_string;
-	
-	gda_init ("GdaMetaStore", "0.1", argc, argv);
+
+	/* set up test environment */
+	g_setenv ("GDA_TOP_SRC_DIR", TOP_SRC_DIR, TRUE);
+	g_setenv ("GDA_TOP_BUILD_DIR", TOP_BUILD_DIR, TRUE);
+	gda_init ();
 
 	/* Clean eveything which might exist in the store */
 	store = gda_meta_store_new (NULL);
