@@ -113,10 +113,11 @@ enum {
 	BUSY,
 	META_CHANGED,
 	FAV_CHANGED,
+	TRANSACTION_STATUS_CHANGED,
 	LAST_SIGNAL
 };
 
-gint browser_connection_signals [LAST_SIGNAL] = { 0, 0, 0 };
+gint browser_connection_signals [LAST_SIGNAL] = { 0, 0, 0, 0 };
 
 GType
 browser_connection_get_type (void)
@@ -176,10 +177,19 @@ browser_connection_class_init (BrowserConnectionClass *klass)
                               NULL, NULL,
                               g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
                               0);
+	browser_connection_signals [TRANSACTION_STATUS_CHANGED] =
+		g_signal_new ("transaction-status-changed",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (BrowserConnectionClass, transaction_status_changed),
+                              NULL, NULL,
+                              g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
+                              0);
 
 	klass->busy = NULL;
 	klass->meta_changed = NULL;
 	klass->favorites_changed = NULL;
+	klass->transaction_status_changed = NULL;
 
 	object_class->dispose = browser_connection_dispose;
 }
@@ -230,6 +240,12 @@ fav_changed_cb (BrowserFavorites *bfav, BrowserConnection *bcnc)
 	g_signal_emit (bcnc, browser_connection_signals [FAV_CHANGED], 0);
 }
 
+static void
+transaction_status_changed_cb (GdaConnection *cnc, BrowserConnection *bcnc)
+{
+	g_signal_emit (bcnc, browser_connection_signals [TRANSACTION_STATUS_CHANGED], 0);
+}
+
 static void
 browser_connection_dispose (GObject *object)
 {
@@ -260,8 +276,12 @@ browser_connection_dispose (GObject *object)
 			g_object_unref (bcnc->priv->p_mstruct);
 		if (bcnc->priv->p_mstruct_mutex)
 			g_mutex_free (bcnc->priv->p_mstruct_mutex);
-		if (bcnc->priv->cnc)
+		if (bcnc->priv->cnc) {
+			g_signal_handlers_disconnect_by_func (bcnc->priv->cnc,
+							      G_CALLBACK (transaction_status_changed_cb),
+							      bcnc);
 			g_object_unref (bcnc->priv->cnc);
+		}
 		if (bcnc->priv->parser)
 			g_object_unref (bcnc->priv->parser);
 		if (bcnc->priv->variables) {
@@ -393,10 +413,14 @@ check_for_wrapper_result (BrowserConnection *bcnc)
 
 /**
  * browser_connection_new
+ * @cnc: a #GdaConnection
  *
- * Creates a new #BrowserConnection object
+ * Creates a new #BrowserConnection object wrapping @cnc. The browser_core_take_connection() method
+ * must be called on the new object to mahe it managed by the browser.
  *
- * Returns: the new object
+ * To close the new connection, use browser_core_close_connection().
+ *
+ * Returns: a new object
  */
 BrowserConnection*
 browser_connection_new (GdaConnection *cnc)
@@ -407,6 +431,8 @@ browser_connection_new (GdaConnection *cnc)
 
 	bcnc = BROWSER_CONNECTION (g_object_new (BROWSER_TYPE_CONNECTION, NULL));
 	bcnc->priv->cnc = g_object_ref (cnc);
+	g_signal_connect (cnc, "transaction-status-changed",
+			  G_CALLBACK (transaction_status_changed_cb), bcnc);
 
 	/* meta store */
 	gchar *dict_file_name = NULL;
@@ -472,6 +498,9 @@ browser_connection_new (GdaConnection *cnc)
 
 /**
  * browser_connection_get_name
+ * @bcnc: a #BrowserConnection
+ *
+ * Returns: @bcnc's name
  */
 const gchar *
 browser_connection_get_name (BrowserConnection *bcnc)
@@ -482,6 +511,11 @@ browser_connection_get_name (BrowserConnection *bcnc)
 
 /**
  * browser_connection_get_information
+ * @bcnc: a #BrowserConnection
+ *
+ * Get some information about the connection
+ *
+ * Returns: a pointer to the associated #GdaDsnInfo
  */
 const GdaDsnInfo *
 browser_connection_get_information (BrowserConnection *bcnc)
@@ -528,6 +562,10 @@ browser_connection_get_information (BrowserConnection *bcnc)
  * @bcnc: a #BrowserConnection
  * @out_reason: a pointer to store a copy of the reason @bcnc is busy (will be set 
  *              to %NULL if @bcnc is not busy)
+ *
+ * Tells if @bcnc is currently busy or not.
+ *
+ * Returns: %TRUE if @bcnc is busy
  */
 gboolean
 browser_connection_is_busy (BrowserConnection *bcnc, gchar **out_reason)
@@ -547,6 +585,9 @@ browser_connection_is_busy (BrowserConnection *bcnc, gchar **out_reason)
 
 /**
  * browser_connection_update_meta_data
+ * @bcnc: a #BrowserConnection
+ *
+ * Make @bcnc update its meta store in the background.
  */
 void
 browser_connection_update_meta_data (BrowserConnection *bcnc)
@@ -578,7 +619,9 @@ browser_connection_update_meta_data (BrowserConnection *bcnc)
 
 /**
  * browser_connection_get_meta_struct
+ * @bcnc: a #BrowserConnection
  *
+ * Get the #GdaMetaStruct maintained up to date by @bcnc.
  *
  * Returns: a #GdaMetaStruct, the caller does not have any reference to it.
  */
@@ -591,9 +634,9 @@ browser_connection_get_meta_struct (BrowserConnection *bcnc)
 
 /**
  * browser_connection_get_meta_store
+ * @bcnc: a #BrowserConnection
  *
- *
- * Returns: a #GdaMetaStore, the caller does not have any reference to it.
+ * Returns: @bcnc's #GdaMetaStore, the caller does not have any reference to it.
  */
 GdaMetaStore *
 browser_connection_get_meta_store (BrowserConnection *bcnc)
@@ -604,6 +647,7 @@ browser_connection_get_meta_store (BrowserConnection *bcnc)
 
 /**
  * browser_connection_get_dictionary_file
+ * @bcnc: a #BrowserConnection
  *
  * Returns: the dictionary file name used by @bcnc, or %NULL
  */
@@ -615,9 +659,68 @@ browser_connection_get_dictionary_file (BrowserConnection *bcnc)
 }
 
 /**
- * browser_connection_get_favorites
+ * browser_connection_get_transaction_status
+ * @bcnc: a #BrowserConnection
  *
- * Get the favorites handler
+ * Retuns: the #GdaTransactionStatus of the connection, or %NULL
+ */
+GdaTransactionStatus *
+browser_connection_get_transaction_status (BrowserConnection *bcnc)
+{
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
+	return gda_connection_get_transaction_status (bcnc->priv->cnc);
+}
+
+/**
+ * browser_connection_begin
+ * @bcnc: a #BrowserConnection
+ * @error: a place to store errors, or %NULL
+ *
+ * Begins a transaction
+ */
+gboolean
+browser_connection_begin (BrowserConnection *bcnc, GError **error)
+{
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), FALSE);
+	return gda_connection_begin_transaction (bcnc->priv->cnc, NULL,
+						 GDA_TRANSACTION_ISOLATION_UNKNOWN, error);
+}
+
+/**
+ * browser_connection_commit
+ * @bcnc: a #BrowserConnection
+ * @error: a place to store errors, or %NULL
+ *
+ * Commits a transaction
+ */
+gboolean
+browser_connection_commit (BrowserConnection *bcnc, GError **error)
+{
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), FALSE);
+	return gda_connection_commit_transaction (bcnc->priv->cnc, NULL, error);
+}
+
+/**
+ * browser_connection_rollback
+ * @bcnc: a #BrowserConnection
+ * @error: a place to store errors, or %NULL
+ *
+ * Rolls back a transaction
+ */
+gboolean
+browser_connection_rollback (BrowserConnection *bcnc, GError **error)
+{
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), FALSE);
+	return gda_connection_rollback_transaction (bcnc->priv->cnc, NULL, error);
+}
+
+/**
+ * browser_connection_get_favorites
+ * @bcnc: a #BrowserConnection
+ *
+ * Get @bcnc's favorites handler
+ *
+ * Returns: the #BrowserFavorites used by @bcnc
  */
 BrowserFavorites *
 browser_connection_get_favorites (BrowserConnection *bcnc)
@@ -631,3 +734,98 @@ browser_connection_get_favorites (BrowserConnection *bcnc)
 	return bcnc->priv->bfav;
 }
 
+/**
+ * browser_connection_create_parser
+ * @bcnc: a #BrowserConnection
+ *
+ * Get a new #GdaSqlParser object for @bcnc
+ *
+ * Returns: a new #GdaSqlParser
+ */
+GdaSqlParser *
+browser_connection_create_parser (BrowserConnection *bcnc)
+{
+	GdaSqlParser *parser;
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
+	
+	parser = gda_connection_create_parser (bcnc->priv->cnc);
+	if (!parser)
+		parser = gda_sql_parser_new ();
+	return parser;
+}
+
+/**
+ * browser_connection_render_pretty_sql
+ * @bcnc: a #BrowserConnection
+ * @stmt: a #GdaStatement
+ *
+ * Renders @stmt as SQL well indented
+ *
+ * Returns: a new string
+ */
+gchar *
+browser_connection_render_pretty_sql (BrowserConnection *bcnc, GdaStatement *stmt)
+{
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
+	g_return_val_if_fail (GDA_IS_STATEMENT (stmt), NULL);
+
+	return gda_statement_to_sql_extended (stmt, bcnc->priv->cnc, NULL,
+					      GDA_STATEMENT_SQL_PRETTY |
+					      GDA_STATEMENT_SQL_PARAMS_SHORT,
+					      NULL, NULL);
+}
+
+/**
+ * browser_connection_execute_statement
+ * @bcnc: a #BrowserConnection
+ * @stmt: a #GdaStatement
+ * @params: a #GdaSet as parameters, or %NULL
+ * @model_usage: how the returned data model (if any) will be used
+ * @need_last_insert_row: %TRUE if the values of the last interted row must be computed
+ * @error: a place to store errors, or %NULL
+ *
+ * Executes @stmt by @bcnc
+ *
+ * Returns: a job ID, to be used with browser_connection_execution_get_result(), or %0 if an
+ * error occurred
+ */
+guint
+browser_connection_execute_statement (BrowserConnection *bcnc,
+				      GdaStatement *stmt,
+				      GdaSet *params,
+				      GdaStatementModelUsage model_usage,
+				      gboolean need_last_insert_row,
+				      GError **error)
+{
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), 0);
+	g_return_val_if_fail (GDA_IS_STATEMENT (stmt), 0);
+	g_return_val_if_fail (!params || GDA_IS_SET (params), 0);
+
+	return gda_connection_async_statement_execute (bcnc->priv->cnc, stmt,
+						       params, model_usage,
+						       NULL, need_last_insert_row,
+						       error);
+}
+
+/**
+ * browser_connection_execution_get_result
+ * @bcnc: a #BrowserConnection
+ * @exec_id: the ID of the excution
+ * @last_insert_row: a place to store the last inserted row, if any, or %NULL
+ * @error: a place to store errors, or %NULL
+ *
+ * Pick up the result of the @exec_id's execution.
+ *
+ * Retunrs: see gda_connection_async_fetch_result()
+ */
+GObject *
+browser_connection_execution_get_result (BrowserConnection *bcnc, guint exec_id,
+					 GdaSet **last_insert_row, GError **error)
+{
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
+	g_return_val_if_fail (exec_id > 0, NULL);
+	
+	return gda_connection_async_fetch_result (bcnc->priv->cnc, exec_id,
+						  last_insert_row,
+						  error);
+}
